==> tekton-model-triggers-v1alpha1-6.5.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/EventListenerFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EventListenerFluentImpl<A extends EventListenerFluent<A>> extends BaseFluent<A> implements EventListenerFluent<A>{
  public EventListenerFluentImpl() {
  }
  public EventListenerFluentImpl(EventListener instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private EventListenerSpecBuilder spec;
  private EventListenerStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public EventListenerFluent.MetadataNested<A> withNewMetadata() {
    return new EventListenerFluentImpl.MetadataNestedImpl();
  }
  public EventListenerFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new EventListenerFluentImpl.MetadataNestedImpl(item);
  }
  public EventListenerFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public EventListenerFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public EventListenerFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public EventListenerSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public EventListenerSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(EventListenerSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new EventListenerSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public EventListenerFluent.SpecNested<A> withNewSpec() {
    return new EventListenerFluentImpl.SpecNestedImpl();
  }
  public EventListenerFluent.SpecNested<A> withNewSpecLike(EventListenerSpec item) {
    return new EventListenerFluentImpl.SpecNestedImpl(item);
  }
  public EventListenerFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public EventListenerFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new EventListenerSpecBuilder().build());
  }
  public EventListenerFluent.SpecNested<A> editOrNewSpecLike(EventListenerSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public EventListenerStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public EventListenerStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(EventListenerStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new EventListenerStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public EventListenerFluent.StatusNested<A> withNewStatus() {
    return new EventListenerFluentImpl.StatusNestedImpl();
  }
  public EventListenerFluent.StatusNested<A> withNewStatusLike(EventListenerStatus item) {
    return new EventListenerFluentImpl.StatusNestedImpl(item);
  }
  public EventListenerFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public EventListenerFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new EventListenerStatusBuilder().build());
  }
  public EventListenerFluent.StatusNested<A> editOrNewStatusLike(EventListenerStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EventListenerFluentImpl that = (EventListenerFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<EventListenerFluent.MetadataNested<N>> implements EventListenerFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) EventListenerFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends EventListenerSpecFluentImpl<EventListenerFluent.SpecNested<N>> implements EventListenerFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(EventListenerSpec item) {
      this.builder = new EventListenerSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new EventListenerSpecBuilder(this);
    }
    EventListenerSpecBuilder builder;
    public N and() {
      return (N) EventListenerFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends EventListenerStatusFluentImpl<EventListenerFluent.StatusNested<N>> implements EventListenerFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(EventListenerStatus item) {
      this.builder = new EventListenerStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new EventListenerStatusBuilder(this);
    }
    EventListenerStatusBuilder builder;
    public N and() {
      return (N) EventListenerFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.2-sources.jar: io/fabric8/tekton/triggers/v1alpha1/EventListenerFluentImpl.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EventListenerFluentImpl<A extends EventListenerFluent<A>> extends BaseFluent<A> implements EventListenerFluent<A>{
  public EventListenerFluentImpl() {
  }
  public EventListenerFluentImpl(EventListener instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private EventListenerSpecBuilder spec;
  private EventListenerStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public EventListenerFluentImpl.MetadataNested<A> withNewMetadata() {
    return new EventListenerFluentImpl.MetadataNestedImpl();
  }
  public EventListenerFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new EventListenerFluentImpl.MetadataNestedImpl(item);
  }
  public EventListenerFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public EventListenerFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public EventListenerFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public EventListenerSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public EventListenerSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(EventListenerSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new EventListenerSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public EventListenerFluentImpl.SpecNested<A> withNewSpec() {
    return new EventListenerFluentImpl.SpecNestedImpl();
  }
  public EventListenerFluentImpl.SpecNested<A> withNewSpecLike(EventListenerSpec item) {
    return new EventListenerFluentImpl.SpecNestedImpl(item);
  }
  public EventListenerFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public EventListenerFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new EventListenerSpecBuilder().build());
  }
  public EventListenerFluentImpl.SpecNested<A> editOrNewSpecLike(EventListenerSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public EventListenerStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public EventListenerStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(EventListenerStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new EventListenerStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public EventListenerFluentImpl.StatusNested<A> withNewStatus() {
    return new EventListenerFluentImpl.StatusNestedImpl();
  }
  public EventListenerFluentImpl.StatusNested<A> withNewStatusLike(EventListenerStatus item) {
    return new EventListenerFluentImpl.StatusNestedImpl(item);
  }
  public EventListenerFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public EventListenerFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new EventListenerStatusBuilder().build());
  }
  public EventListenerFluentImpl.StatusNested<A> editOrNewStatusLike(EventListenerStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EventListenerFluentImpl that = (EventListenerFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<EventListenerFluentImpl.MetadataNested<N>> implements EventListenerFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) EventListenerFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends EventListenerSpecFluentImpl<EventListenerFluentImpl.SpecNested<N>> implements EventListenerFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(EventListenerSpec item) {
      this.builder = new EventListenerSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new EventListenerSpecBuilder(this);
    }
    EventListenerSpecBuilder builder;
    public N and() {
      return (N) EventListenerFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends EventListenerStatusFluentImpl<EventListenerFluentImpl.StatusNested<N>> implements EventListenerFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(EventListenerStatus item) {
      this.builder = new EventListenerStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new EventListenerStatusBuilder(this);
    }
    EventListenerStatusBuilder builder;
    public N and() {
      return (N) EventListenerFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
